@@ -508,8 +508,8 @@ class Bootstrap:
                 df_tgt.s_trec  = ['', sign_tgt_rec]
             print(str_out)
             if self.savetsv:
-                df_tot.to_csv(f"{self.dirout}results.tsv")
-                df_tgt.to_csv(f"{self.dirout}results_targetclass.tsv")
+                df_tot.to_csv(f"{self.dirout}results.tsv", sep="\t")
+                df_tgt.to_csv(f"{self.dirout}results_targetclass.tsv", sep="\t")
             return df_tot, df_tgt
         else:
             diff_jsd = df_tot.d_jsd[-1]
@@ -549,7 +549,7 @@ class Bootstrap:
             df_tot.s_cor = ['', sign_cor]
             print(str_out)
             if self.savetsv:
-                df_tot.to_csv(f"{self.dirout}results.tsv")
+                df_tot.to_csv(f"{self.dirout}results.tsv", sep="\t")
             return df_tot, df_tgt
 
     def run(self, n_loops=1000, sample_size=.1, targetclass=None, verbose=False):
@@ -649,13 +649,13 @@ class Bootstrap:
             df_both = pd.concat([df_tot, df_tgt.iloc[:, 1:]], axis=1)
             print(df_both.to_string())
             if self.savetsv:
-                df_tgt.to_csv(f"{self.dirout}results_targetclass.tsv")
-                df_both.to_csv(f"{self.dirout}results_overall.tsv")
+                df_tgt.to_csv(f"{self.dirout}results_targetclass.tsv", sep="\t")
+                df_both.to_csv(f"{self.dirout}results_overall.tsv", sep="\t")
         else:
             print(df_tot.to_string())
         if self.savejson:
             self.data2json(f"{self.dirout}outcomes.json")
         if self.savetsv:
-            df_tot.to_csv(f"{self.dirout}results.tsv")
+            df_tot.to_csv(f"{self.dirout}results.tsv", sep="\t")
         end(startime)
         return df_tot, df_tgt
